@@ -1,6 +1,8 @@
 import sys
 import cv2
-sys.path.append("D:\Programs\Python\Python39\Lib\site-packages\mpqcv")
+import os
+lib_path = (os.path.split(os.path.realpath(__file__))[0])
+sys.path.append(lib_path)
 from My_CV import *
 # -*- coding utf-8 -*-
 """
@@ -106,8 +108,8 @@ def minRect(c):
 def drawRect(frame,rect):
     frame = draw_rect(frame,rect)
     return frame
-def drawCircle(img,center,r,index):
-    img =draw_circle(img,center,r,index)
+def drawCircle(img,center,r,color,thickness,txt_key=1,index=1):
+    img = draw_circle(img,center,r,color,thickness,txt_key,index)
     return  img
 def matchC(c1,c2):
     retval = match_c(c1,c2)
@@ -138,11 +140,13 @@ def getGray(img1,channal):
 if __name__ == '__main__':
     showName('./test2.jpg',0)
     img = readGraypic('./test2.jpg')
+    img = drawCircle(img,(100,100),30,255,-1,txt_key=0)
+    show_img(img,0)
     # CMs = get_Color_oments(img)
     # print(CMs)
     # img = cv2.cvtColor(img,cv2.COLOR_BGR2GRAY)
     # new_pic = cut_pic(img,100,10,1,1)
     # show_img(new_pic,0)
-    glgcm = get_Glgcm(img)
-    print(glgcm)
+    # glgcm = get_Glgcm(img)
+    # print(glgcm)
 
